@@ -133,10 +133,10 @@ QScrollArea{
         self.urldb = os.path.join(settings.__file__.replace('settings.py', "database"), "url.db")
         self.FilesBtn.clicked.connect(self.setFilePath)
         self.DirsBtn.clicked.connect(self.setDirPath)
-        self.FunctionName = "Word转PDF"
+        self.FunctionName = "这是移动文件到层级文件夹"
         self.describetion = '''
 =================================================
-这是Word转PDF的描述信息
+这是移动文件到层级文件夹
 =================================================
 '''
 
